##############
Account Module
##############

The *Account Module* defines the fundamentals needed for basic double entry
accounting.
It also includes templates for the `basic universal chart of accounts
<https://www.ifrs-gaap.com/basic-universal-coa>`_, balance sheet and income
statement.

.. toctree::
   :maxdepth: 2

   setup
   usage/index
   design/index
   reference
   releases
